==> djangosaml2-knaperek-0.14.0.tar.gz: djangosaml2-knaperek-0.14.0/setup.py <==
# Copyright (C) 2011-2012 Yaco Sistemas <lgs@yaco.es>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#            http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()


setup(
    name='djangosaml2-knaperek',
    version='0.14.0',
    description='pysaml2 integration for Django',
    long_description='\n\n'.join([read('README'), read('CHANGES')]),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
        "Topic :: Security",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        ],
    keywords="django,pysaml2,saml2,federated authentication,authentication",
    author="Yaco Sistemas",
    author_email="lgs@yaco.es",
    maintainer="Jozef Knaperek",
    url="https://bitbucket.org/knaperek/djangosaml2",
    download_url="https://pypi.python.org/pypi/djangosaml2-knaperek/",
    license='Apache 2.0',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'pysaml2==4.0.2',
        'python-memcached==1.48',
        ],
    )

==> djangosaml2-knaperek-0.14.1.tar.gz: djangosaml2-knaperek-0.14.1/setup.py <==
# Copyright (C) 2011-2012 Yaco Sistemas <lgs@yaco.es>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#            http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()


setup(
    name='djangosaml2-knaperek',
    version='0.14.1',
    description='pysaml2 integration for Django',
    long_description='\n\n'.join([read('README.rst'), read('CHANGES')]),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI",
        "Topic :: Security",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        ],
    keywords="django,pysaml2,saml2,federated authentication,authentication",
    author="Yaco Sistemas",
    author_email="lgs@yaco.es",
    maintainer="Jozef Knaperek",
    url="https://bitbucket.org/knaperek/djangosaml2",
    download_url="https://pypi.python.org/pypi/djangosaml2-knaperek/",
    license='Apache 2.0',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'pysaml2==4.0.4',
        'python-memcached==1.48',
        ],
    )
